@@ -1,6 +1,6 @@
 #############################################################################
 #################         Easy Debugging Module        ######################
-################# Copyright 2013 - 2015 Richard Kelsch ######################
+################# Copyright 2013 - 2016 Richard Kelsch ######################
 #################          All Rights Reserved         ######################
 #############################################################################
 ####### Licensing information available near the end of this file. ##########
@@ -21,11 +21,17 @@ use Time::HiRes qw(time);
 use File::Basename;
 use Data::Dumper;
 
+our $THREADS = FALSE;
+eval {
+    use threads;
+    $THREADS = TRUE;
+};
+
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.11;
+    our $VERSION = 1.13;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -214,6 +220,9 @@ DEFAULT:  '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] '
 %Fork%       = Running in parent or child?
      P = Parent
      C = Child
+%Thread%     = Running in Parent or Thread
+     P   = Parent
+     T## = Thread # = Thread ID
 
 =item B<[loglevel]-Prefix> [pattern]
 
@@ -575,6 +584,13 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
     my $Time   = $dt->hms();
     my $prefix = $self->{$level . '-PREFIX'} . '';    # A copy not a pointer
     my $forked = ($PARENT ne $$) ? 'C' : 'P';
+    my $threaded = 'P--';
+    if ($THREADS) {
+        eval {
+            my $tid = threads->tid();
+            $threaded = ($tid > 0) ? sprintf('T%02',$tid) : 'P--';
+        };
+    }
 
     $prefix =~ s/\%PID\%/$$/g;
     $prefix =~ s/\%Loglevel\%/$ANSILevel{$level}/g;
@@ -587,6 +603,7 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
     $prefix =~ s/\%time\%/$Time/g;
     $prefix =~ s/\%Filename\%/$self->{'FILENAME'}/g;
     $prefix =~ s/\%Fork\%/$forked/g;
+    $prefix =~ s/\%Thread\%/$threaded/g;
     $prefix =~ s/\%Module\%/$subroutine/g;
 
     if ($first) {
